pro mk_sff,  week,  outdir=outdir, loud=loud, refresh=refresh, $
  noscatter=noscatter, nodeka=nodeka, nokleen=nokleen, novignette=novignette,$
  prefix=prefix,  ss=ss
;+
;   Name: mk_sff
;
;   Purpose: make SXT "Final" science composite movie - de-spagetti mk_sfd
;
;   Input Parameters:
;      week - the week to process
; 
;   Output Parameters:
;     NONE
;
;   Keyword Parameters:
;      nodeka     - dont deka normalize
;      novignette - dont vignette correct
;      nokleen    - dont call sxt_kleen (despike)
;      noscatter  - dont call sxt_scatter
;
;      prefix - output file prefix (default='sff' (pair), 'sfq' implies triple 
;  
;   Side Effects:
;      generates an 'sff' file - floating point, deka-normalized    
;   
;   History:
;      14-Sep-1998 - S.L.Freeland  - Written (YPOP/MSU)
;      16-Sep-1998 - Various mods - include proc flags in file name.
;      17-Sep-1998 - Add scattered light correction and /NOSCATTER
;-
;
; 
common mk_sff_blk1, lweek, files, roadmap

mk_sff_version='.01'  

; Processing Flags (boolean in file name of form xxxx (0=>off,1=>on)
; ORDER>>       SCATTER | VIGNETTE | KLEEN | DEKA 

scatter=1-keyword_set(noscatter)
vignette=1-keyword_set(novignette)
kleen=1-keyword_set(nokleen)
deka=1-keyword_set(nodeka)

; - make the processing flags part of the file name - 
flagstring=strcompress(string(scatter)+ $
  string(vignette)+string(kleen)+string(deka),/remove)

if not keyword_set(outdir) then outdir=curdir()
outfil=concat_dir(outdir,'sff'+week+'_'+flagstring+mk_sff_version)

states=(['DISABLED','ENABLED'])
status=['Output File Name: ' + outfil,      $
  'Processing Options:',                    $
  'Scattered Light:    ' + states(scatter), $
  'Vignette Correction:' + states(vignette),$
  'SXT_Kleen (despike):' + states(kleen),   $
  'DEKA-Sec Normalize: ' + states(deka) ]

if not data_chk(week,/string) then begin
   box_message,'supply week...'           
   return
endif 

box_message,status

loud=keyword_set(loud)

if n_elements(lweek) eq 0 then lweek=''
refresh = keyword_set(refresh) or lweek ne week
if refresh then begin 
;   --- temporary --- LMSAL specific cdrom reader...
   box_message,'TEMPORARY - (cdrom_files) '
   files=cdfiles(week,prefix=sfr)
   rd_roadmap,files,roadmap
   lweek=week
endif

; -------- make LONG/SHORT pariings ----------
if loud then box_message,'Calling image-paring routine...'
mk_sff_pair, roadmap, ssl, sss, delta
nlong=n_elements(ssl)
if n_elements(ss) ne 0 then nlong=ss

if loud then box_message,'Number of pairs found: ' + strtrim(nlong,2)

for i=0,nlong -1 do begin
  rd_sda,files,[ssl(i),sss(i)],index,data                ; !CAREFUL ORDER!
; ---------- dont composite if not required ---------
  satlong=sxt_satscreen(index(0),data(*,*,0))   
  
  if not satlong then begin

     if loud then box_message,['Compositing Image Pair:', $
	 get_info(roadmap(ssl(i)),/non),get_info(roadmap(sss(i)),/non)]

;    ---- Call compositing routine (calls sxt_prep internally) ---
     sxt_sff_composite, index, data, cindex, cdata, $
        vignette=vignette, sxt_kleen=kleen

   endif else begin
     if loud then box_message,['No compositing required for: ', $
	 get_info(roadmap(ssl(i)),/non)]

;      ----- No compositing needed - just call sxt_prep ---------
       sxt_prep, index(0),data(*,*,0), cindex, cdata, $
          /float,/dc_orbit_correct,vignette=vignette, sxt_kleen=kleen

   endelse
  
   if scatter then begin 
      box_message,'Removing scatter'
      sxt_scatter2, cindex, cdata, scatindex, scatdata
      cindex=scatindex
      cdata=float(double(cdata)-double(scatdata))
   endif

   if deka then begin
       box_message,'DEKA-Normalizing'       
       cdata=deka_norm(cindex, cdata, deka=cindex)       
   endif
   sav_sda,outfil,cindex,cdata,append=(i ne 0)
endfor  

return
end

