pro mk_sff_pair, infil, ssl, sss, delta
;+
;   Name: mk_sff_pair
;
;   Purpose: make pairings for SXT full disk composite movies
;
;   Input Parameters:
;      infil - list of SFR files OR roadmaps
;
;   Output Paramters:
;      ssl - subscripts of LONG exposures matching criteria  
;      sss - subscripts of associated SHORT exposures
;      delta - deltaT (long:short)
;  
;   History:
;      14-apr-1998 - S.L.Freeland - break/rework mk_sfd
;-

; ------- input (sfr file list or ROADMAP ) ------
if data_chk(infil,/struct) then roadmap=infil else $   ; file or roadmap ok
    rd_roadmap, infil, roadmap, filidx=filidx
; -----------------------------------------------

tim2orbit, roadmap, tim2night=tim2night                 ; get all time2nights

; -------- Define uniq pairing combinations ------
res=  [1,2]            ; half / quarter
fb=   [2,3]            ; Al.1 / AlMg
; -----------------------------------------------

; --------- initialize output variables ------------
ssl=[-1]                                        ; long subscripts
sss=[-1]                                        ; paired subscripts
delta=[-1]                                      ; dT (long:short)
; -----------------------------------------------

for resx=0,n_elements(res)-1 do begin           ; for each resolution
   for filtb=0,n_elements(fb)-1 do begin        ; for each filter 

;    ------ Flag promising LONG exposures ---------
     ssli=where(roadmap.percentd eq 255 and gt_filtb(roadmap) eq fb(filtb) and $
	gt_filta(roadmap) eq 1 and $					;mdm added 29-Nov-93
	gt_res(roadmap) eq res(resx) and gt_expmode(roadmap) eq 0 and $
	gt_dpe(roadmap) ge 17 and gt_dpe(roadmap) le 25 and $
        (gt_shape_cmd(roadmap,/x) eq gt_shape_cmd(roadmap,/y)) and $	; slf 9-oct
	tim2night gt 2.0,sslcnt)	;	roadmap.img_max gt 150)

;    ------- SHORT exposures w/matching resolution and filter ----------
     sssi=where(roadmap.percentd eq 255 and gt_filtb(roadmap) eq fb(filtb) and $				;MDM start adding 22-Apr-92
	gt_filta(roadmap) eq 1 and $					;mdm added 29-Nov-93
	gt_res(roadmap) eq res(resx) and gt_expmode(roadmap) eq 0 and $
	gt_dpe(roadmap) ge 9 and gt_dpe(roadmap) le 15 and $
        (gt_shape_cmd(roadmap,/x) eq gt_shape_cmd(roadmap,/y)) and $	; slf 9-oct
	tim2night gt 2.0,ssscnt)

;     ----- For every LONG, identify closest SHORT which passes filter ----
      if ssscnt gt 0 and sslcnt gt 0 then begin
         dts2l=tim2dset(roadmap(sssi),roadmap(ssli),delta=dt) 

;        update SS and delta output variables
         ssl=[ssl,ssli]
         sss=[sss,sssi(dts2l)]
         delta=[delta,dt]
       endif
       mess=['#images w/filter:'+gt_filtb(fb(filtb),/string) + $
	     ', resolution: '+  gt_res(res(resx),/string)+' : ' + strtrim(ssscnt,2)]
       box_message,mess
   endfor
endfor
; -----------------------------------------------

; --------------- eliminate inital value -----------
ssl=ssl(1:*)
sss=sss(1:*)
delta=delta(1:*)
; -----------------------------------------------

; ------------- time sort all output  ------------
order=sort_index(roadmap(ssl),/ss)
ssl=ssl(order)
sss=sss(order)
delta=delta(order)
; -----------------------------------------------

return
end

