
PRO sxt_scatter2, compindex, compdata, scatindex, scatdata, $
        level=level, power=power
;+
;
; INPUT PARAMETERS:
;       compindex - index record associated with composite
;	compdata  - composite image, Full frame.
;       ;
; CALLING SEQUENCE
;	sxt_scatter2,compindex,compdata, scatindex, scatdata
;
; OUTPUT PARAMETERS:
;	scatindex - scattered light image (with history record indicator)
;       scatdata  - scattered light data
;
; OPTIONAL INPUT KEYWORDS:
;	level = level of scattered light.  Default = 0.00168.
;	power = power-law index of scattered light.  Default = -1.89
;
; RESTRICTIONS:
;	The scattering function is only valid for the thin filters:
;	Al.1, AlMg, Mg3.
;	Uses Fourier transforms for convolution.
;	USES BIG ARRAYS, TAKES TIME, USES MEMORY.
;
; HISTORY:
;	Written June 17, 1994   Barry LaBonte
;	Cleaned up the code   June 21, 1994  BJL
;	Default values are Acton's result for 6-Sep-92 image  June 23,1994 BJL
;	30-Oct-96 [LWA]  Generalized method of determining pixel size.
;       17-Sep-1998 - S.L.Freeland - review/standard call sequence,
;                     Return HIS adjusted index record
;                     rename to sxt_scatter2
;-

if not data_chk(compindex,/struct) or n_params() lt 3 then begin 
   box_message,'IDL> sxt_scatter2, comp_index, comp_data, scatter 
endif

pix=gt_pix_size(compindex)/gt_pix_size(1)

; How big is the input?
nx=data_chk(compdata,/nx)
ny=data_chk(compdata,/ny)

; Handle keywords
IF( KEYWORD_SET(level) NE 0 ) THEN slevel = level ELSE slevel = 0.00168
IF( KEYWORD_SET(power) NE 0 ) THEN spower = power ELSE spower = -1.89

; SCATTER FUNCTION  -----------------------------------------------
; Radius^2 = x^2 + y^2
psf = ( FINDGEN( 2*nx ) - nx )^2
psf = REBIN( psf, 2*nx, 2*ny )
ypsf = ( FINDGEN( 2*ny ) - ny )^2
ypsf = REFORM( ypsf, 1, 2*ny )
ypsf = REBIN( ypsf, 2*nx, 2*ny )
psf = TEMPORARY(psf) + ypsf
ypsf = 0

; Shift center of function to (0,0)
psf = SHIFT( TEMPORARY(psf), -nx, ny )
psf(0,0) = 1.

; Get the correct function
psf = slevel * pix^(2+spower) * TEMPORARY(psf)^(spower/2)
psf(0,0) = 1.

; Find the correct normalization
pnorm = REBIN( psf, 1, 1 )

; "Subtract" the original image
psf(0,0) = 0.

; Take the Fourier Transform
psf = FFT( TEMPORARY(psf)/pnorm(0), -1 )

; NOW THE IMAGE  ------------------------------------------------
; Insert into double sized array to avoid Fourier wraparound
big = FLTARR( 2*nx, 2*ny )
big(nx/2:nx-1+nx/2, ny/2:ny-1+ny/2) = compdata

; Transform,  convolve, and back transform
big = FFT( ( FFT( TEMPORARY(big), -1 ) * psf ), 1 )

; Extract the valid region
scatdata = FLOAT( TEMPORARY( big(nx/2:nx-1+nx/2, ny/2:ny-1+ny/2) ) )

; ----------- update history record --------------
his_index,/enable
scatindex=compindex
extra=scatindex.his.q_extra
extra(1)=1
his_index,scatindex,0,'q_extra',extra
; --------------------------------------------------

RETURN
END
